@@ -121,13 +121,13 @@ class ISchedulerTaskInfo(Interface):
     def getNextRun(self):
         """Get next task execution time"""
 
-    def run(self, db, root, site, report):
+    def run(self, report, **kw):
         """Launch job execution"""
 
     def storeReport(self, report, status):
         """Store execution report in task's history and send it by mail"""
 
-    def sendReport(self, report):
+    def sendReport(self, report, status, target=None):
         """Store execution report in task's history and send it by mail"""
 
 
